<!DOCTYPE TS><TS>
<context>
    <name>QObject</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Next Interface</source>
        <translation>Nächste Schnittstelle</translation>
    </message>
    <message>
        <source>Use</source>
        <translation>Benutze</translation>
    </message>
    <message>
        <source>KPhone found more than one interface.</source>
        <translation>KPhone hat mehr als eine Schnittstelle gefunden.</translation>
    </message>
    <message>
        <source>Do you want to use the default interface:</source>
        <translation>Möchten Sie die Standard-Schnittstelle benutzen?</translation>
    </message>
    <message>
        <source>Do you want to use</source>
        <translation>Verfügbare Schnittstelle:</translation>
    </message>
    <message>
        <source>Permanently rejected contacts</source>
        <translation>Dauerhaft abgelehnte Kontakte</translation>
    </message>
    <message>
        <source>Call Register</source>
        <translation>Anrufverzeichnis</translation>
    </message>
    <message>
        <source>Received calls</source>
        <translation>Angenommene Anrufe</translation>
    </message>
    <message>
        <source>Missed calls</source>
        <translation>Verpasste Anrufe</translation>
    </message>
    <message>
        <source>PhoneBook</source>
        <translation>Telefonbuch</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>AudioControl</name>
    <message>
        <source>Audio Properties</source>
        <translation>Audio-Eigenschaften</translation>
    </message>
    <message>
        <source>OSS Device Mode</source>
        <translation>OSS-Gerätemodus</translation>
    </message>
    <message>
        <source>ReadWrite</source>
        <translation>Lesen/Schreiben</translation>
    </message>
    <message>
        <source>ReadOnly / WriteOnly</source>
        <translation>Nur Lesen / Nur Schreiben</translation>
    </message>
    <message>
        <source>Device for WriteOnly or ReadWrite:</source>
        <translation>Gerät für Nur-Schreib- oder Lese/Schreib-Zugriff:</translation>
    </message>
    <message>
        <source>Device for ReadOnly:</source>
        <translation>Gerät für Nur-Lese-Zugriff:</translation>
    </message>
    <message>
        <source>Preferred Codec</source>
        <translation>Bevorzugter Codec</translation>
    </message>
    <message>
        <source>G711u</source>
        <translation></translation>
    </message>
    <message>
        <source>GSM</source>
        <translation></translation>
    </message>
    <message>
        <source>iLBC</source>
        <translation></translation>
    </message>
    <message>
        <source>Size of Payload</source>
        <translation>Größe der Dateneinheiten</translation>
    </message>
    <message>
        <source>80 (10 ms Sample)</source>
        <translation></translation>
    </message>
    <message>
        <source>160 (20 ms Sample)</source>
        <translation></translation>
    </message>
    <message>
        <source>Ringing tone  (system bell)</source>
        <translation>Rufton (Systemton)</translation>
    </message>
    <message>
        <source>Don&apos;t use ringing tone</source>
        <translation>Kein Klingelton</translation>
    </message>
    <message>
        <source>Use ringing tone</source>
        <translation>Verwende Klingelton</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>OK-Knopf</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>Abbrechen-Knopf</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>CallAudio</name>
    <message>
        <source>CallAudio: SendToRemote called but we don&apos;t have a valid session description yet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Remote is currently putting us on hold, waiting patiently</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Sending to remote site %s:%d</source>
        <translation>CallAudio: Sende an die Gegenstelle %s:%d</translation>
    </message>
    <message>
        <source>CallAudio: OSS device already open (readwrite)</source>
        <translation>CallAudio: Das OSS-Gerät ist bereits geöffnet (Lesen/Schreiben)</translation>
    </message>
    <message>
        <source>** audioIn: openDevice Failed.</source>
        <translation>** audioIn: openDevice fehlgeschlagen.</translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Input</source>
        <translation>CallAudio: Öffne OSS-Gerät %s zum Lesen</translation>
    </message>
    <message>
        <source>CallAudio: Creating OSS-&gt;RTP Diverter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: Opening SW for video input and output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CallAudio: listening for incomming RTP</source>
        <translation>CallAudio: warte auf eingehende RTP-Verbindungen</translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Input and Output</source>
        <translation>CallAudio: Öffne OSS-Gerät %s zum Schreiben und Lesen</translation>
    </message>
    <message>
        <source>** audioOut: openDevice Failed.</source>
        <translation>** audioOut: openDevice fehlgeschlagen.</translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Output</source>
        <translation>CallAudio: Öffne OSS-Gerät %s zum Schreiben</translation>
    </message>
</context>
<context>
    <name>ContactParser</name>
    <message>
        <source>description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>uri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactsListView</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
</context>
<context>
    <name>DspAudioIn</name>
    <message>
        <source>DspAudioIn: Broken pipe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DspAudioIn: UDP-failure(%d)</source>
        <translation>DspAudioIn: UDP-Fehler (%d)</translation>
    </message>
</context>
<context>
    <name>DspAudioOut</name>
    <message>
        <source>DspAudio: Broken pipe</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DspOutOss</name>
    <message>
        <source>Device Already Open</source>
        <translation>Gerät ist bereits geöffnet</translation>
    </message>
    <message>
        <source>Open Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format not supported</source>
        <translation>Das Format wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Unsupported Number of Channels</source>
        <translation>Nicht-unterstützte Anzahl an Kanälen</translation>
    </message>
    <message>
        <source>WARNING: nonmonophonic driver, forced into stereo mode (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WARNING: driver rounded %d Hz request to %d Hz, off by %f%%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device Not Open</source>
        <translation>Gerät ist nicht geöffnet</translation>
    </message>
    <message>
        <source>warning: asked microphone for %d got %d</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DspOutRtp</name>
    <message>
        <source>DspOutRtp:: Can&apos;t create socket</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DspOutRtp::Hostname lookup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SipClient: Receiving message...</source>
        <translation>SipClient: Empfange Nachricht ...</translation>
    </message>
    <message>
        <source>SipClient: STUN response for RTP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KCallTransfer</name>
    <message>
        <source>Transfer to URI:</source>
        <translation>Zu URI transferieren:</translation>
    </message>
    <message>
        <source>help button</source>
        <translation>Hilfe-Knopf</translation>
    </message>
    <message>
        <source>&amp;help...</source>
        <translation>&amp;Hilfe...</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>OK Knopf</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>Abbrechen-Knopf</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>KCallWidget</name>
    <message>
        <source>Remote: </source>
        <translation>Gegenüber:</translation>
    </message>
    <message>
        <source>  Remote:  </source>
        <translation>  Gegenüber:  </translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Audio: </source>
        <translation>Audio:</translation>
    </message>
    <message>
        <source>Dial</source>
        <translation>Wählen</translation>
    </message>
    <message>
        <source>Hangup</source>
        <translation>Auflegen</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Halten</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transferieren</translation>
    </message>
    <message>
        <source>DTMF</source>
        <translation>DTMF</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Verstecken</translation>
    </message>
    <message>
        <source>KCallWidget: Switching calls...
</source>
        <translation>KCallWidget: Wechsle Anrufe...
</translation>
    </message>
    <message>
        <source>Call: </source>
        <translation>Anruf:</translation>
    </message>
    <message>
        <source>Incoming Video Call: </source>
        <translation>Eingehender Videoanruf:</translation>
    </message>
    <message>
        <source>Incoming Call: </source>
        <translation>Eingehender Anruf:</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Annehmen</translation>
    </message>
    <message>
        <source>Reject</source>
        <translation>Abweisen</translation>
    </message>
    <message>
        <source>Outgoing Video Call: </source>
        <translation>Ausgehender Videoanruf:</translation>
    </message>
    <message>
        <source>Outgoing Call: </source>
        <translation>Ausgehender Anruf:</translation>
    </message>
    <message>
        <source>Error: No Destination</source>
        <translation>Fehler: Kein Ziel</translation>
    </message>
    <message>
        <source>You must specify someone to call.</source>
        <translation>Sie müssen den Anzurufenden eingeben.</translation>
    </message>
    <message>
        <source>Close any program which might be using soundcard 
and then retry dial.</source>
        <translation>Schließen Sie alle Programme, die die Soundkarte verwenden 
könnten und versuchen Sie es erneut.</translation>
    </message>
    <message>
        <source>KCallAudio: Broken output pipe, disconnecting unpolitely
</source>
        <translation>KCallAudio: Broken output pipe, trenne
</translation>
    </message>
    <message>
        <source>Unhold</source>
        <translation>Nicht mehr halten</translation>
    </message>
    <message>
        <source>KCallWidget: Handling redirect...
</source>
        <translation>KCallWidget: Verarbeite Umleitung...
</translation>
    </message>
    <message>
        <source>Redirect</source>
        <translation>Umleiten</translation>
    </message>
    <message>
        <source>Call redirected to: 
</source>
        <translation>Anruf umgeleitet zu:</translation>
    </message>
    <message>
        <source>Do you want to proceed ? </source>
        <translation>Möchten Sie fortfahren?</translation>
    </message>
    <message>
        <source>KCallWidget: Starting force disconnect...
</source>
        <translation>KCallWidget: Beginne erzwungene Trennung...
</translation>
    </message>
    <message>
        <source>Attached [holding]</source>
        <translation>verbunden [gehalten]</translation>
    </message>
    <message>
        <source>Attached [active]</source>
        <translation>verbunden [aktiv]</translation>
    </message>
    <message>
        <source>Unattached</source>
        <translation>nicht verbunden</translation>
    </message>
    <message>
        <source>ERROR: %s
</source>
        <comment>Open Failed</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept Call</source>
        <translation>Anruf annehmen</translation>
    </message>
    <message>
        <source>Close any program which might be using soundcard 
and then retry accepting call.</source>
        <translation>Schließen Sie alle Programme, die die Soundkarte verwenden 
könnten und versuchen Sie erneut., den Anruf anzunehmen.</translation>
    </message>
    <message>
        <source>Accepted codec not found.</source>
        <translation>Akzeptierter Codec nicht gefunden.</translation>
    </message>
</context>
<context>
    <name>KInstantMessageWidget</name>
    <message>
        <source> Message - KPhone</source>
        <translation>Nachricht - KPhone</translation>
    </message>
    <message>
        <source>Remote: </source>
        <translation>Gegenüber:</translation>
    </message>
    <message>
        <source>  Remote:  </source>
        <translation>  Gegenüber:  </translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Message: </source>
        <translation>Nachricht:</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Verstecken</translation>
    </message>
    <message>
        <source>
Message received from </source>
        <translation>
Nachricht empfangen von</translation>
    </message>
    <message>
        <source>Error: No Destination</source>
        <translation>Fehler: Kein Ziel</translation>
    </message>
    <message>
        <source>You must specify someone to send message.</source>
        <translation>Sie müssen jemanden auswählen, um einen Nachricht zu senden.</translation>
    </message>
    <message>
        <source>
Message sent to </source>
        <translation>
Nachricht gesendet an</translation>
    </message>
</context>
<context>
    <name>KPhone</name>
    <message>
        <source>New Call...</source>
        <translation>&amp;Neuer Anruf...</translation>
    </message>
    <message>
        <source>New Video Call...</source>
        <translation>Neuer &amp;Videoanruf...</translation>
    </message>
    <message>
        <source>Identity...</source>
        <translation>&amp;Identität...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>SIP Preferences...</source>
        <translation>SIP-Eigenschaften...</translation>
    </message>
    <message>
        <source>Audio Preferences...</source>
        <translation>Audio-Eigenschaften...</translation>
    </message>
    <message>
        <source>Video Preferences...</source>
        <translation>Video-Eigenschaften...</translation>
    </message>
    <message>
        <source>Phone Book</source>
        <translation>Telefonbuch...</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Tray-Symbol</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Eigenschaften</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>About KPhone</source>
        <translation>Über KPhone</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>When starting KPhone for the first time, you should enter your identity information in the window appearing.
The information required for successful sipping are &apos;Full Name&apos;, &apos;User part of SIP URL&apos; and &apos;Host part of SIP URL&apos;.
Note for KPhone 3.xx users: copy &apos;~/.kde/share/config/kphonerc&apos; file to &apos;~/.qt&apos; directory.

If you have a NAPTR/SRV enabled DNS-server you can leave the &apos;Outbound Proxy&apos; and &apos;Authentication Username&apos; fields empty,
as KPhone will automatically search for the server information by the &apos;Host part of SIP URL&apos; and prompt the username/password.

Mark the auto register selection if you wish KPhone to automatically register your identity on application start.
If you want to use multiple identities, start KPhone with the &apos;-u&apos; option and the username of your selection.
For example:  &apos;kphone -u jsmith&apos;.

If you are behind a NAT (Network Address Translation) device, you should go to Preferences -&gt; SIP Preferences -&gt; Socket and
check the &apos;Use STUN Server&apos;

The right button of your mouse is your best friend in KPhone&apos;s main UI. By clicking the right mouse button (RMB) in the main
window you get a menu including all important functions of KPhone. You should edit the Phone Book and enter all your favourite
contacts there. Of course this is not mandatory but it increases your efficiency with KPhone.

When adding contacts to your Phone Book, simply click Add and enter the person&apos;s real name, SIP identity and the optional
description. If you want your contacts to be displayed in the main UI, just check the &apos;Add Identity ...&apos; box. After editing your
contacts you can return to the main UI by clicking Hide. All your selected contacts should now appear there. Making calls and 
sending instant messages to your contacts is easy with the RMB. Just click and select the function which you&apos;d like to initiate.
</source>
        <translation>Wenn Sie KPhone zum ersten Mal starten, sollten Sie Ihre Identitätsinformationen im erscheinenden Fenster eingeben.
Die notwendigen Informationen sind &quot;Vor- und Nachname&quot;, &quot;Benutzer-Teil der SIP URL&quot; sowie &quot;Host-Teil der SIP URL&quot;
Hinweis für KPhone 3.x-Benutzer: Kopieren Sie &apos;~/.kde/share/config/kphonerc&apos; in das &apos;~/.qt&apos; Verzeichnis.

Falls Sie einen DNS-Server mit aktiviertem NAPTR/SRV verwenden, können Sie die &apos;Ausgehender Proxy&apos; und &apos;Authentifizierungs Benutzername&apos; freilassen,
da KPhone automatisch nach den Serverinformationen durch &apos;Host-Teil der SIP URL&apos; suchen wird und den Benutzernamen/Passwort abfragt.

Wählen Sie &apos;Automatisch anmelden&apos; wenn sich KPhone nach dem Start automatisch anmelden soll.
Falls Sie mehrere Identitäten verwenden möchten, starten Sie KPhone mit &apos;-u&apos; und dem Benutzernamen.
Zum Beispiel:  &apos;kphone -u jsmith&apos;

Wenn Sie sich hinter einem NAT (Network Address Translation) befinden, sollten Sie unter Einstellungen -&gt; SIP Einstellungen -&gt; Socket  &apos;STUN-Server verwenden&apos; auswählen.

Der rechte Mausbutton ist Ihr bester Freund im Benutzerinterface von KPhone. Mit dem rechten Mausbutton im
Hauptfenster bekommen Sie ein Menü mit allen wichtigen Funktionen von KPhone. Sie sollten das Telefonbuch 
bearbeiten und alle Ihre wichtigen Kontakte eingeben. Dies ist natürlich nicht notwendig, erhöht aber Ihre Effizienz 
in KPhone.

Wenn Sie Kontake zum Telefonbuch hinzufügen, klicken Sie einfach auf Hinzufügen und geben Sie den Namen,
 SIP-Identität und die optionale Beschreibung ein. Wenn Ihre Kontakte im Hauptfenster angezeigt werden sollen, 
klicken Sie einfach auf die &apos;Identität hinzufügen&apos; Box. Nach der Bearbeitung Ihrer Kontakte, können Sie mittels
 Verstecken zum Hauptmenü zurückkehren. Alle Ihre ausgewählten Kontakte sollten nun dort erscheinen.
Anrufe tätigen und Kurznachrichten an Ihre Kontakte senden ist mit dem rechten Mausbutton ganz einfach. Klicken
Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
</translation>
    </message>
    <message>
        <source>is a &apos;Voice Over Internet&apos; phone</source>
        <translation>ist ein Software-Telefon für die &apos;Internet-Telefonie&apos;</translation>
    </message>
    <message>
        <source>Copyright (c) 2000 Billy Biggs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright (c) 2004 Wirlab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KPhone is released under the GPL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>For more information, see</source>
        <translation>Weitere Informationen erhalten Sie unter</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation>Verstecken</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation>Anzeigen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>KPhoneView</name>
    <message>
        <source>Set Identity</source>
        <translation>Identität festlegen</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Nachricht senden</translation>
    </message>
    <message>
        <source>Call</source>
        <translation>Anrufen</translation>
    </message>
    <message>
        <source>Video Call</source>
        <translation>Videoanruf</translation>
    </message>
    <message>
        <source>Phone Book</source>
        <translation>Telefonbuch</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Online</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Be Right Back</source>
        <translation>Bin gleich zurück</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Unterwegs</translation>
    </message>
    <message>
        <source>On The Phone</source>
        <translation>Am Telefon</translation>
    </message>
    <message>
        <source>Out To Lunch</source>
        <translation>Mittagessen</translation>
    </message>
    <message>
        <source>KPhoneView: Incoming Instant Message</source>
        <translation>KPhoneView: Eingehende Kurznachricht</translation>
    </message>
    <message>
        <source>KPhone</source>
        <translation>KPhone</translation>
    </message>
    <message>
        <source>Subscribe message from uri:</source>
        <translation>Subscribe-Nachricht von uri:</translation>
    </message>
    <message>
        <source>Do you want to accept and create a contact ?</source>
        <translation>Wollen Sie akzeptieren und einen neuen Kontakt anlegen?</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Akzeptieren</translation>
    </message>
    <message>
        <source>Reject permanently</source>
        <translation>Permanent abweisen</translation>
    </message>
    <message>
        <source>Reject this time</source>
        <translation>Diesmal abweisen</translation>
    </message>
    <message>
        <source>Incoming call</source>
        <translation>Eingehender Anruf</translation>
    </message>
    <message>
        <source>Set First Identity.</source>
        <translation>Erste Identität festlegen.</translation>
    </message>
    <message>
        <source>online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>busy</source>
        <translation>beschäftigt</translation>
    </message>
    <message>
        <source>berightback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>away</source>
        <translation>abwesend</translation>
    </message>
    <message>
        <source>onthephone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>outtolunch</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSipAuthenticationRequest</name>
    <message>
        <source>SipUri = </source>
        <translation>SIP URI = </translation>
    </message>
    <message>
        <source>Server = </source>
        <translation>Server = </translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>OK-Knopf</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>Abbrechen-Knopf</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>KSipIdentityEdit</name>
    <message>
        <source>Identity Editor</source>
        <translation>Identitäts-Editor</translation>
    </message>
    <message>
        <source>Full Name:</source>
        <translation>Vor- und Nachname:</translation>
    </message>
    <message>
        <source>User Part of SIP URL:</source>
        <translation>Benutzer-Teil der SIP-URL:</translation>
    </message>
    <message>
        <source>Host Part of SIP URL:</source>
        <translation>Host-Teil der SIP-URL:</translation>
    </message>
    <message>
        <source>Outbound Proxy (optional):</source>
        <translation>Ausgehender Proxy (optional):</translation>
    </message>
    <message>
        <source>Authentication Username (optional):</source>
        <translation>Authentifizierungs-Benutzername (optional):</translation>
    </message>
    <message>
        <source>q-value between 0.0-1.0 (optional):</source>
        <translation>q-Wert zwischen 0.0-1.0 (optional):</translation>
    </message>
    <message>
        <source>Auto Register</source>
        <translation>Automatisch anmelden</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>Unregister</source>
        <translation>Abmeldung</translation>
    </message>
    <message>
        <source>help button</source>
        <translation>Hilfe-Knopf</translation>
    </message>
    <message>
        <source>&amp;help...</source>
        <translation>&amp;Hilfe...</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>OK-Knopf</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>Abbrechen-Knopf</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Registration : not registered</source>
        <translation>Registrierung : nicht registriert</translation>
    </message>
    <message>
        <source>Registration : registered</source>
        <translation>Registrierung : registriert</translation>
    </message>
</context>
<context>
    <name>KSipOptions</name>
    <message>
        <source>URI to Request Options For:</source>
        <translation>URI für die Anfrage von Optionen:</translation>
    </message>
    <message>
        <source>Results:</source>
        <translation>Ergebnisse:</translation>
    </message>
    <message>
        <source>Make Query</source>
        <translation>Anfrage starten</translation>
    </message>
</context>
<context>
    <name>KSipPreferences</name>
    <message>
        <source>Global SIP Preferences</source>
        <translation>Globale SIP-Einstellungen</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Hide Via</source>
        <translation>Via verstecken</translation>
    </message>
    <message>
        <source>Don&apos;t Hide</source>
        <translation>Nicht verstecken</translation>
    </message>
    <message>
        <source>Request Next Hop</source>
        <translation>Nächsten Hop erfragen</translation>
    </message>
    <message>
        <source>Request Full Route</source>
        <translation>Vollständige Route erfragen</translation>
    </message>
    <message>
        <source>Max Forwards</source>
        <translation>Max. Weiterleitungen</translation>
    </message>
    <message>
        <source>XML-File for Phone Book:</source>
        <translation>XML-Datei für Telefonbuch:</translation>
    </message>
    <message>
        <source>Expire Time of Registration (second):</source>
        <translation>Verfallszeit der Registrierung (Sekunden):</translation>
    </message>
    <message>
        <source>Expire Time of Presence Subscription (second):</source>
        <translation>Verfallszeit der Anwesenheitsanmeldung (Sekunden):</translation>
    </message>
    <message>
        <source>Socket Protocol (Kphone restart needed to apply change)</source>
        <translation>Socket Protokoll (Kphone Neustart nötig, um die Änderungen zu speichern)</translation>
    </message>
    <message>
        <source>Use STUN Server</source>
        <translation>Verwenden STUN-Server</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Symmetric Signalling</source>
        <translation>Symmetrische Signalisierung</translation>
    </message>
    <message>
        <source>Symmetric Media</source>
        <translation>Symmetrische Medien</translation>
    </message>
    <message>
        <source>STUN Server (address:port):</source>
        <translation>STUN-Server (Adresse:Port):</translation>
    </message>
    <message>
        <source>Request Period for STUN Server (second):</source>
        <translation>Anfrageintervall für STUN-Server (Sekunden):</translation>
    </message>
    <message>
        <source>Media Min Port:</source>
        <translation>Min. Medienport:</translation>
    </message>
    <message>
        <source>Media Max Port:</source>
        <translation>Max. Medienport:</translation>
    </message>
    <message>
        <source>Call Preferences</source>
        <translation>Anrufeinstellungen</translation>
    </message>
    <message>
        <source>Busy Message:</source>
        <translation>Beschäftigt-Nachricht:</translation>
    </message>
    <message>
        <source>Call Forwarding</source>
        <translation>Anrufweiterleitung</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inaktiv</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Forward to:</source>
        <translation>Weiterleiten zu:</translation>
    </message>
    <message>
        <source>Call Forward Message:</source>
        <translation>Anrufweiterleitung Nachricht:</translation>
    </message>
</context>
<context>
    <name>KSipRegistrations</name>
    <message>
        <source>off</source>
        <translation>aus</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Rufnummer</translation>
    </message>
    <message>
        <source>Restart Kphone to apply identity changes.</source>
        <translation>Starten Sie Kphone neu, um die Änderungen zu speichern.</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inaktiv</translation>
    </message>
    <message>
        <source>Trying...</source>
        <translation>Probiere...</translation>
    </message>
    <message>
        <source>Auth Required...</source>
        <translation>Anmeldung benötigt...</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Unregistering...</source>
        <translation>Abmelden...</translation>
    </message>
    <message>
        <source>Reregistering...</source>
        <translation>Erneut anmelden...</translation>
    </message>
    <message>
        <source>Digest Authentication Request</source>
        <translation>Digest-Authentifizierungsanfrage</translation>
    </message>
    <message>
        <source>Basic Authentication Request</source>
        <translation>Einfache (basic) Authentifizierungsanfrage</translation>
    </message>
    <message>
        <source>Proxy Digest Authentication Request</source>
        <translation>Proxy Digest Authentifizierungsanfrage</translation>
    </message>
    <message>
        <source>Proxy Basic Authentication Request</source>
        <translation>Proxy Basic Authentifizierungsanfrage</translation>
    </message>
</context>
<context>
    <name>KTestOptions</name>
    <message>
        <source>Address:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Nachricht:</translation>
    </message>
    <message>
        <source>Clean</source>
        <translation>Säubern</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Textdateien (*.txt)</translation>
    </message>
    <message>
        <source>open file dialogChoose a file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PhoneBook</name>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Verstecken</translation>
    </message>
    <message>
        <source>Permanently rejected contacts</source>
        <translation>Immer abgewiesene Kontakte</translation>
    </message>
    <message>
        <source>PhoneBook</source>
        <translation>Telefonbuch</translation>
    </message>
    <message>
        <source>KPhone</source>
        <translation>KPhone</translation>
    </message>
    <message>
        <source>Select first item.</source>
        <translation>Erstes Objekt wählen.</translation>
    </message>
    <message>
        <source>Are You Sure ?</source>
        <translation>Sind Sie sicher?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>PhoneBookAddIdentity</name>
    <message>
        <source>Person:</source>
        <translation>Person:</translation>
    </message>
    <message>
        <source>Identity:</source>
        <translation>Identität:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Add Identity to Contacts List</source>
        <translation>Zur Kontaktliste hinzufügen</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>OK-Knopf</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>Abbrechen-Knopf</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>PhoneBookEditIdentity</name>
    <message>
        <source>Identity:</source>
        <translation>Identität:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Add Identity to Contacts List</source>
        <translation>Zur Kontaktliste hinzufügen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>PhoneBookEditPerson</name>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>PhoneBookParser</name>
    <message>
        <source>Identity</source>
        <translation>Identität</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Permanently rejected contacts</source>
        <translation>Dauerhaft abgelehnte Kontakte</translation>
    </message>
    <message>
        <source>Call Register</source>
        <translation>Anrufverzeichnis</translation>
    </message>
    <message>
        <source>Received calls</source>
        <translation>Angenommene Anrufe</translation>
    </message>
    <message>
        <source>Missed calls</source>
        <translation>Verpasste Anrufe</translation>
    </message>
    <message>
        <source>PhoneBook</source>
        <translation>Telefonbuch</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>contact</source>
        <translation>Kontakt</translation>
    </message>
</context>
<context>
    <name>SipCallMember</name>
    <message>
        <source>Response: </source>
        <translation></translation>
    </message>
    <message>
        <source>Connected: </source>
        <translation>Verbunden: </translation>
    </message>
    <message>
        <source>Redirected: </source>
        <translation>Umgeleitet: </translation>
    </message>
    <message>
        <source>Call Failed: </source>
        <translation>Anruf fehlgeschlagen: </translation>
    </message>
    <message>
        <source>Disconnecting</source>
        <translation>Abbauen</translation>
    </message>
    <message>
        <source>Transfering</source>
        <translation>Transferieren</translation>
    </message>
    <message>
        <source>Querying options</source>
        <translation>Anfrage-Optionen</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Verbunden</translation>
    </message>
    <message>
        <source>Call Failed</source>
        <translation>Anruf fehlgeschlagen</translation>
    </message>
    <message>
        <source>Not Acceptable Here</source>
        <translation></translation>
    </message>
    <message>
        <source>Rejecting call invitation</source>
        <translation>Anruf wird abgelehnt</translation>
    </message>
    <message>
        <source>Invitation received</source>
        <translation></translation>
    </message>
    <message>
        <source>Session update requested</source>
        <translation>Sitzungsaktualisierung angefordert</translation>
    </message>
    <message>
        <source>Remote end disconnected</source>
        <translation>Gegenstelle getrennt</translation>
    </message>
    <message>
        <source>Refer</source>
        <translation></translation>
    </message>
    <message>
        <source>Request cancelled</source>
        <translation>Anfrage abgebrochen</translation>
    </message>
    <message>
        <source>No Response</source>
        <translation>Keine Antwort</translation>
    </message>
    <message>
        <source>Trying</source>
        <translation>Anrufversuch</translation>
    </message>
    <message>
        <source>Ringing</source>
        <translation>Rufen</translation>
    </message>
    <message>
        <source>Call is Being Forwarded</source>
        <translation>Anruf wird weitergeleitet</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>In Warteschlange</translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation>Nicht erlaubt</translation>
    </message>
    <message>
        <source>Not Found</source>
        <translation>Nicht gefunden</translation>
    </message>
</context>
<context>
    <name>SipTransaction</name>
    <message>
        <source>Online</source>
        <translation></translation>
    </message>
    <message>
        <source>Busy</source>
        <translation></translation>
    </message>
    <message>
        <source>Be Right Back</source>
        <translation></translation>
    </message>
    <message>
        <source>Away</source>
        <translation></translation>
    </message>
    <message>
        <source>On The Phone</source>
        <translation></translation>
    </message>
    <message>
        <source>Out To Lunch</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoControl</name>
    <message>
        <source>Video Properties</source>
        <translation>Videoeigenschaften</translation>
    </message>
    <message>
        <source>Preferred Video Codec</source>
        <translation>Bevorzugter Videocodec</translation>
    </message>
    <message>
        <source>H261</source>
        <translation>H261</translation>
    </message>
    <message>
        <source>H263</source>
        <translation>H263</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>OK-Knopf</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>Abbrechen-Knopf</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
</TS>
